/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.bigquery.model;

import com.google.api.client.json.GenericJson;
import com.google.api.client.json.JsonString;

/**
 * Model definition for Dataset.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the BigQuery API. For a detailed explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class Dataset extends GenericJson {

  /**
   * [Optional] Describes users' rights on the dataset. You can assign the same role to multiple
   * users, and assign multiple roles to the same user. Default values assigned to a new dataset are
   * as follows: OWNER - Project owners, dataset creator READ - Project readers WRITE - Project
   * writers See ACLs and Rights for a description of these rights. If you specify any of these
   * roles when creating a dataset, the assigned roles will overwrite the defaults listed above. To
   * revoke rights to a dataset, call datasets.update() and omit the names of anyone whose rights
   * you wish to revoke. However, every dataset must have at least one entity granted OWNER role.
   * Each access object can have only one of the following members: userByEmail, groupByEmail,
   * domain, or allAuthenticatedUsers.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<Access> access;

  static {
    // hack to force ProGuard to consider Access used, since otherwise it would be stripped out
    // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
    com.google.api.client.util.Data.nullOf(Access.class);
  }

  /**
   * [Output-only] The time when this dataset was created, in milliseconds since the epoch.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key @JsonString
  private Long creationTime;

  /**
   * [Required] Reference identifying dataset.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private DatasetReference datasetReference;

  /**
   * [Optional] A user-friendly string description for the dataset. This might be shown in BigQuery
   * UI for browsing the dataset.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String description;

  /**
   * [Output-only] A hash of this resource.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String etag;

  /**
   * [Optional] A descriptive name for this dataset, which might be shown in any BigQuery user
   * interfaces for browsing the dataset. Use datasetId for making API calls.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String friendlyName;

  /**
   * [Output-only] The fully-qualified unique name of this dataset in the format
   * projectId:datasetId. The dataset name without the project name is given in the datasetId field.
   * When creating a new dataset, leave this field blank, and instead specify the datasetId field.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String id;

  /**
   * [Output-only] The resource type.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String kind;

  /**
   * [Output-only] The date when this dataset or any of its tables was last modified, in
   * milliseconds since the epoch.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key @JsonString
  private Long lastModifiedTime;

  /**
   * [Output-only] An URL that can be used to access this resource again. You can use this URL in
   * Get or Update requests to this resource.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String selfLink;

  /**
   * [Optional] Describes users' rights on the dataset. You can assign the same role to multiple
   * users, and assign multiple roles to the same user. Default values assigned to a new dataset are
   * as follows: OWNER - Project owners, dataset creator READ - Project readers WRITE - Project
   * writers See ACLs and Rights for a description of these rights. If you specify any of these
   * roles when creating a dataset, the assigned roles will overwrite the defaults listed above. To
   * revoke rights to a dataset, call datasets.update() and omit the names of anyone whose rights
   * you wish to revoke. However, every dataset must have at least one entity granted OWNER role.
   * Each access object can have only one of the following members: userByEmail, groupByEmail,
   * domain, or allAuthenticatedUsers.
   * The value returned may be {@code null}.
   */
  public java.util.List<Access> getAccess() {
    return access;
  }

  /**
   * [Optional] Describes users' rights on the dataset. You can assign the same role to multiple
   * users, and assign multiple roles to the same user. Default values assigned to a new dataset are
   * as follows: OWNER - Project owners, dataset creator READ - Project readers WRITE - Project
   * writers See ACLs and Rights for a description of these rights. If you specify any of these
   * roles when creating a dataset, the assigned roles will overwrite the defaults listed above. To
   * revoke rights to a dataset, call datasets.update() and omit the names of anyone whose rights
   * you wish to revoke. However, every dataset must have at least one entity granted OWNER role.
   * Each access object can have only one of the following members: userByEmail, groupByEmail,
   * domain, or allAuthenticatedUsers.
   * The value set may be {@code null}.
   */
  public Dataset setAccess(java.util.List<Access> access) {
    this.access = access;
    return this;
  }

  /**
   * [Output-only] The time when this dataset was created, in milliseconds since the epoch.
   * The value returned may be {@code null}.
   */
  public Long getCreationTime() {
    return creationTime;
  }

  /**
   * [Output-only] The time when this dataset was created, in milliseconds since the epoch.
   * The value set may be {@code null}.
   */
  public Dataset setCreationTime(Long creationTime) {
    this.creationTime = creationTime;
    return this;
  }

  /**
   * [Required] Reference identifying dataset.
   * The value returned may be {@code null}.
   */
  public DatasetReference getDatasetReference() {
    return datasetReference;
  }

  /**
   * [Required] Reference identifying dataset.
   * The value set may be {@code null}.
   */
  public Dataset setDatasetReference(DatasetReference datasetReference) {
    this.datasetReference = datasetReference;
    return this;
  }

  /**
   * [Optional] A user-friendly string description for the dataset. This might be shown in BigQuery
   * UI for browsing the dataset.
   * The value returned may be {@code null}.
   */
  public String getDescription() {
    return description;
  }

  /**
   * [Optional] A user-friendly string description for the dataset. This might be shown in BigQuery
   * UI for browsing the dataset.
   * The value set may be {@code null}.
   */
  public Dataset setDescription(String description) {
    this.description = description;
    return this;
  }

  /**
   * [Output-only] A hash of this resource.
   * The value returned may be {@code null}.
   */
  public String getEtag() {
    return etag;
  }

  /**
   * [Output-only] A hash of this resource.
   * The value set may be {@code null}.
   */
  public Dataset setEtag(String etag) {
    this.etag = etag;
    return this;
  }

  /**
   * [Optional] A descriptive name for this dataset, which might be shown in any BigQuery user
   * interfaces for browsing the dataset. Use datasetId for making API calls.
   * The value returned may be {@code null}.
   */
  public String getFriendlyName() {
    return friendlyName;
  }

  /**
   * [Optional] A descriptive name for this dataset, which might be shown in any BigQuery user
   * interfaces for browsing the dataset. Use datasetId for making API calls.
   * The value set may be {@code null}.
   */
  public Dataset setFriendlyName(String friendlyName) {
    this.friendlyName = friendlyName;
    return this;
  }

  /**
   * [Output-only] The fully-qualified unique name of this dataset in the format
   * projectId:datasetId. The dataset name without the project name is given in the datasetId field.
   * When creating a new dataset, leave this field blank, and instead specify the datasetId field.
   * The value returned may be {@code null}.
   */
  public String getId() {
    return id;
  }

  /**
   * [Output-only] The fully-qualified unique name of this dataset in the format
   * projectId:datasetId. The dataset name without the project name is given in the datasetId field.
   * When creating a new dataset, leave this field blank, and instead specify the datasetId field.
   * The value set may be {@code null}.
   */
  public Dataset setId(String id) {
    this.id = id;
    return this;
  }

  /**
   * [Output-only] The resource type.
   * The value returned may be {@code null}.
   */
  public String getKind() {
    return kind;
  }

  /**
   * [Output-only] The resource type.
   * The value set may be {@code null}.
   */
  public Dataset setKind(String kind) {
    this.kind = kind;
    return this;
  }

  /**
   * [Output-only] The date when this dataset or any of its tables was last modified, in
   * milliseconds since the epoch.
   * The value returned may be {@code null}.
   */
  public Long getLastModifiedTime() {
    return lastModifiedTime;
  }

  /**
   * [Output-only] The date when this dataset or any of its tables was last modified, in
   * milliseconds since the epoch.
   * The value set may be {@code null}.
   */
  public Dataset setLastModifiedTime(Long lastModifiedTime) {
    this.lastModifiedTime = lastModifiedTime;
    return this;
  }

  /**
   * [Output-only] An URL that can be used to access this resource again. You can use this URL in
   * Get or Update requests to this resource.
   * The value returned may be {@code null}.
   */
  public String getSelfLink() {
    return selfLink;
  }

  /**
   * [Output-only] An URL that can be used to access this resource again. You can use this URL in
   * Get or Update requests to this resource.
   * The value set may be {@code null}.
   */
  public Dataset setSelfLink(String selfLink) {
    this.selfLink = selfLink;
    return this;
  }

  /**
   * Model definition for DatasetAccess.
   */
  public static final class Access extends GenericJson {

    /**
     * [Pick one] A domain to grant access to. Any users signed in with the domain specified will be
     * granted the specified access. Example: "example.com".
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String domain;

    /**
     * [Pick one] A fully-qualified email address of a mailing list to grant access to. This must be
     * either a Google Groups mailing list (ends in @googlegroups.com) or a group managed by an
     * enterprise version of Google Groups.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String groupByEmail;

    /**
     * [Required] Describes the rights granted to the user specified by the other member of the access
     * object. The following string values are supported: READ - User can call any list() or get()
     * method on any collection or resource. WRITE - User can call any method on any collection except
     * for datasets, on which they can call list() and get(). OWNER - User can call any method. The
     * dataset creator is granted this role by default.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String role;

    /**
     * [Pick one] A special group to grant access to. The valid values are: projectOwners: Owners of
     * the enclosing project. projectReaders: Readers of the enclosing project. projectWriters:
     * Writers of the enclosing project. allAuthenticatedUsers: All authenticated BigQuery users.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String specialGroup;

    /**
     * [Pick one] A fully qualified email address of a user to grant access to. For example:
     * fred@example.com.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String userByEmail;

    /**
     * [Pick one] A domain to grant access to. Any users signed in with the domain specified will be
     * granted the specified access. Example: "example.com".
     * The value returned may be {@code null}.
     */
    public String getDomain() {
      return domain;
    }

    /**
     * [Pick one] A domain to grant access to. Any users signed in with the domain specified will be
     * granted the specified access. Example: "example.com".
     * The value set may be {@code null}.
     */
    public Access setDomain(String domain) {
      this.domain = domain;
      return this;
    }

    /**
     * [Pick one] A fully-qualified email address of a mailing list to grant access to. This must be
     * either a Google Groups mailing list (ends in @googlegroups.com) or a group managed by an
     * enterprise version of Google Groups.
     * The value returned may be {@code null}.
     */
    public String getGroupByEmail() {
      return groupByEmail;
    }

    /**
     * [Pick one] A fully-qualified email address of a mailing list to grant access to. This must be
     * either a Google Groups mailing list (ends in @googlegroups.com) or a group managed by an
     * enterprise version of Google Groups.
     * The value set may be {@code null}.
     */
    public Access setGroupByEmail(String groupByEmail) {
      this.groupByEmail = groupByEmail;
      return this;
    }

    /**
     * [Required] Describes the rights granted to the user specified by the other member of the access
     * object. The following string values are supported: READ - User can call any list() or get()
     * method on any collection or resource. WRITE - User can call any method on any collection except
     * for datasets, on which they can call list() and get(). OWNER - User can call any method. The
     * dataset creator is granted this role by default.
     * The value returned may be {@code null}.
     */
    public String getRole() {
      return role;
    }

    /**
     * [Required] Describes the rights granted to the user specified by the other member of the access
     * object. The following string values are supported: READ - User can call any list() or get()
     * method on any collection or resource. WRITE - User can call any method on any collection except
     * for datasets, on which they can call list() and get(). OWNER - User can call any method. The
     * dataset creator is granted this role by default.
     * The value set may be {@code null}.
     */
    public Access setRole(String role) {
      this.role = role;
      return this;
    }

    /**
     * [Pick one] A special group to grant access to. The valid values are: projectOwners: Owners of
     * the enclosing project. projectReaders: Readers of the enclosing project. projectWriters:
     * Writers of the enclosing project. allAuthenticatedUsers: All authenticated BigQuery users.
     * The value returned may be {@code null}.
     */
    public String getSpecialGroup() {
      return specialGroup;
    }

    /**
     * [Pick one] A special group to grant access to. The valid values are: projectOwners: Owners of
     * the enclosing project. projectReaders: Readers of the enclosing project. projectWriters:
     * Writers of the enclosing project. allAuthenticatedUsers: All authenticated BigQuery users.
     * The value set may be {@code null}.
     */
    public Access setSpecialGroup(String specialGroup) {
      this.specialGroup = specialGroup;
      return this;
    }

    /**
     * [Pick one] A fully qualified email address of a user to grant access to. For example:
     * fred@example.com.
     * The value returned may be {@code null}.
     */
    public String getUserByEmail() {
      return userByEmail;
    }

    /**
     * [Pick one] A fully qualified email address of a user to grant access to. For example:
     * fred@example.com.
     * The value set may be {@code null}.
     */
    public Access setUserByEmail(String userByEmail) {
      this.userByEmail = userByEmail;
      return this;
    }

  }

}
