/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.bigquery.model;

import com.google.api.client.json.GenericJson;

/**
 * Model definition for DatasetList.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the BigQuery API. For a detailed explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class DatasetList extends GenericJson {

  /**
   * An array of one or more summarized dataset resources. Absent when there are no datasets in the
   * specified project.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<Datasets> datasets;

  static {
    // hack to force ProGuard to consider Datasets used, since otherwise it would be stripped out
    // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
    com.google.api.client.util.Data.nullOf(Datasets.class);
  }

  /**
   * A hash of this page of results. See Paging Through Results in the developer's guide.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String etag;

  /**
   * The type of list.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String kind;

  /**
   * A token to request the next page of results. Present only when there is more than one page of
   * results.* See Paging Through Results in the developer's guide.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String nextPageToken;

  /**
   * An array of one or more summarized dataset resources. Absent when there are no datasets in the
   * specified project.
   * The value returned may be {@code null}.
   */
  public java.util.List<Datasets> getDatasets() {
    return datasets;
  }

  /**
   * An array of one or more summarized dataset resources. Absent when there are no datasets in the
   * specified project.
   * The value set may be {@code null}.
   */
  public DatasetList setDatasets(java.util.List<Datasets> datasets) {
    this.datasets = datasets;
    return this;
  }

  /**
   * A hash of this page of results. See Paging Through Results in the developer's guide.
   * The value returned may be {@code null}.
   */
  public String getEtag() {
    return etag;
  }

  /**
   * A hash of this page of results. See Paging Through Results in the developer's guide.
   * The value set may be {@code null}.
   */
  public DatasetList setEtag(String etag) {
    this.etag = etag;
    return this;
  }

  /**
   * The type of list.
   * The value returned may be {@code null}.
   */
  public String getKind() {
    return kind;
  }

  /**
   * The type of list.
   * The value set may be {@code null}.
   */
  public DatasetList setKind(String kind) {
    this.kind = kind;
    return this;
  }

  /**
   * A token to request the next page of results. Present only when there is more than one page of
   * results.* See Paging Through Results in the developer's guide.
   * The value returned may be {@code null}.
   */
  public String getNextPageToken() {
    return nextPageToken;
  }

  /**
   * A token to request the next page of results. Present only when there is more than one page of
   * results.* See Paging Through Results in the developer's guide.
   * The value set may be {@code null}.
   */
  public DatasetList setNextPageToken(String nextPageToken) {
    this.nextPageToken = nextPageToken;
    return this;
  }

  /**
   * Model definition for DatasetListDatasets.
   */
  public static final class Datasets extends GenericJson {

    /**
     * Reference identifying dataset.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private DatasetReference datasetReference;

    /**
     * A descriptive name for this dataset, if one exists.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String friendlyName;

    /**
     * The fully-qualified unique name of this dataset in the format projectId:datasetId.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String id;

    /**
     * The resource type.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String kind;

    /**
     * Reference identifying dataset.
     * The value returned may be {@code null}.
     */
    public DatasetReference getDatasetReference() {
      return datasetReference;
    }

    /**
     * Reference identifying dataset.
     * The value set may be {@code null}.
     */
    public Datasets setDatasetReference(DatasetReference datasetReference) {
      this.datasetReference = datasetReference;
      return this;
    }

    /**
     * A descriptive name for this dataset, if one exists.
     * The value returned may be {@code null}.
     */
    public String getFriendlyName() {
      return friendlyName;
    }

    /**
     * A descriptive name for this dataset, if one exists.
     * The value set may be {@code null}.
     */
    public Datasets setFriendlyName(String friendlyName) {
      this.friendlyName = friendlyName;
      return this;
    }

    /**
     * The fully-qualified unique name of this dataset in the format projectId:datasetId.
     * The value returned may be {@code null}.
     */
    public String getId() {
      return id;
    }

    /**
     * The fully-qualified unique name of this dataset in the format projectId:datasetId.
     * The value set may be {@code null}.
     */
    public Datasets setId(String id) {
      this.id = id;
      return this;
    }

    /**
     * The resource type.
     * The value returned may be {@code null}.
     */
    public String getKind() {
      return kind;
    }

    /**
     * The resource type.
     * The value set may be {@code null}.
     */
    public Datasets setKind(String kind) {
      this.kind = kind;
      return this;
    }

  }

}
