/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.bigquery.model;

import com.google.api.client.json.GenericJson;
import com.google.api.client.json.JsonString;
import com.google.common.primitives.UnsignedLong;

/**
 * Model definition for ProjectList.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the BigQuery API. For a detailed explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class ProjectList extends GenericJson {

  /**
   * A hash of the page of results
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String etag;

  /**
   * The type of list.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String kind;

  /**
   * A token to request the next page of results.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String nextPageToken;

  /**
   * Projects to which you have at least READ access.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<Projects> projects;

  static {
    // hack to force ProGuard to consider Projects used, since otherwise it would be stripped out
    // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
    com.google.api.client.util.Data.nullOf(Projects.class);
  }

  /**
   * The total number of projects in the list.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Integer totalItems;

  /**
   * A hash of the page of results
   * The value returned may be {@code null}.
   */
  public String getEtag() {
    return etag;
  }

  /**
   * A hash of the page of results
   * The value set may be {@code null}.
   */
  public ProjectList setEtag(String etag) {
    this.etag = etag;
    return this;
  }

  /**
   * The type of list.
   * The value returned may be {@code null}.
   */
  public String getKind() {
    return kind;
  }

  /**
   * The type of list.
   * The value set may be {@code null}.
   */
  public ProjectList setKind(String kind) {
    this.kind = kind;
    return this;
  }

  /**
   * A token to request the next page of results.
   * The value returned may be {@code null}.
   */
  public String getNextPageToken() {
    return nextPageToken;
  }

  /**
   * A token to request the next page of results.
   * The value set may be {@code null}.
   */
  public ProjectList setNextPageToken(String nextPageToken) {
    this.nextPageToken = nextPageToken;
    return this;
  }

  /**
   * Projects to which you have at least READ access.
   * The value returned may be {@code null}.
   */
  public java.util.List<Projects> getProjects() {
    return projects;
  }

  /**
   * Projects to which you have at least READ access.
   * The value set may be {@code null}.
   */
  public ProjectList setProjects(java.util.List<Projects> projects) {
    this.projects = projects;
    return this;
  }

  /**
   * The total number of projects in the list.
   * The value returned may be {@code null}.
   */
  public Integer getTotalItems() {
    return totalItems;
  }

  /**
   * The total number of projects in the list.
   * The value set may be {@code null}.
   */
  public ProjectList setTotalItems(Integer totalItems) {
    this.totalItems = totalItems;
    return this;
  }

  /**
   * Model definition for ProjectListProjects.
   */
  public static final class Projects extends GenericJson {

    /**
     * A descriptive name for this project.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String friendlyName;

    /**
     * An opaque ID of this project.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String id;

    /**
     * The resource type.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String kind;

    /**
     * The numeric ID of this project.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key @JsonString
    private UnsignedLong numericId;

    /**
     * A unique reference to this project.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private ProjectReference projectReference;

    /**
     * A descriptive name for this project.
     * The value returned may be {@code null}.
     */
    public String getFriendlyName() {
      return friendlyName;
    }

    /**
     * A descriptive name for this project.
     * The value set may be {@code null}.
     */
    public Projects setFriendlyName(String friendlyName) {
      this.friendlyName = friendlyName;
      return this;
    }

    /**
     * An opaque ID of this project.
     * The value returned may be {@code null}.
     */
    public String getId() {
      return id;
    }

    /**
     * An opaque ID of this project.
     * The value set may be {@code null}.
     */
    public Projects setId(String id) {
      this.id = id;
      return this;
    }

    /**
     * The resource type.
     * The value returned may be {@code null}.
     */
    public String getKind() {
      return kind;
    }

    /**
     * The resource type.
     * The value set may be {@code null}.
     */
    public Projects setKind(String kind) {
      this.kind = kind;
      return this;
    }

    /**
     * The numeric ID of this project.
     * The value returned may be {@code null}.
     */
    public UnsignedLong getNumericId() {
      return numericId;
    }

    /**
     * The numeric ID of this project.
     * The value set may be {@code null}.
     */
    public Projects setNumericId(UnsignedLong numericId) {
      this.numericId = numericId;
      return this;
    }

    /**
     * A unique reference to this project.
     * The value returned may be {@code null}.
     */
    public ProjectReference getProjectReference() {
      return projectReference;
    }

    /**
     * A unique reference to this project.
     * The value set may be {@code null}.
     */
    public Projects setProjectReference(ProjectReference projectReference) {
      this.projectReference = projectReference;
      return this;
    }

  }

}
