/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.bigquery.model;

import com.google.api.client.json.GenericJson;

/**
 * Model definition for QueryRequest.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the BigQuery API. For a detailed explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class QueryRequest extends GenericJson {

  /**
   * [Optional] Specifies the default datasetId and projectId to assume for any unqualified table
   * names in the query. If not set, all table names in the query string must be fully-qualified in
   * the format projectId:datasetId.tableid.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private DatasetReference defaultDataset;

  /**
   * [Optional] If set, don't actually run the query. A valid query will return an empty response,
   * while an invalid query will return the same error it would if it wasn't a dry run.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Boolean dryRun;

  /**
   * The resource type of the request.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String kind;

  /**
   * [Optional] The maximum number of results to return per page of results. If the response list
   * exceeds the maximum response size for a single response, you will have to page through the
   * results. Default is to return the maximum response size.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Long maxResults;

  /**
   * [Experimental] If set, preserve null values in table data, rather than mapping null values to
   * the column's default value. This flag currently defaults to false, but the default will soon be
   * changed to true. Shortly afterward, this flag will be removed completely. Please specify true
   * if possible, and false only if you need to force the old behavior while updating client code.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Boolean preserveNulls;

  /**
   * [Required] A query string, following the BigQuery query syntax of the query to execute. Table
   * names should be qualified by dataset name in the format projectId:datasetId.tableId unless you
   * specify the defaultDataset value. If the table is in the same project as the job, you can omit
   * the project ID. Example: SELECT f1 FROM myProjectId:myDatasetId.myTableId.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String query;

  /**
   * [Optional] How long to wait for the query to complete, in milliseconds, before returning.
   * Default is to return immediately. If the timeout passes before the job completes, the request
   * will fail with a TIMEOUT error.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Long timeoutMs;

  /**
   * [Optional] Whether to look for the result in the query cache. The query cache is a best-effort
   * cache that will be flushed whenever tables in the query are modified.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Boolean useQueryCache;

  /**
   * [Optional] Specifies the default datasetId and projectId to assume for any unqualified table
   * names in the query. If not set, all table names in the query string must be fully-qualified in
   * the format projectId:datasetId.tableid.
   * The value returned may be {@code null}.
   */
  public DatasetReference getDefaultDataset() {
    return defaultDataset;
  }

  /**
   * [Optional] Specifies the default datasetId and projectId to assume for any unqualified table
   * names in the query. If not set, all table names in the query string must be fully-qualified in
   * the format projectId:datasetId.tableid.
   * The value set may be {@code null}.
   */
  public QueryRequest setDefaultDataset(DatasetReference defaultDataset) {
    this.defaultDataset = defaultDataset;
    return this;
  }

  /**
   * [Optional] If set, don't actually run the query. A valid query will return an empty response,
   * while an invalid query will return the same error it would if it wasn't a dry run.
   * The value returned may be {@code null}.
   */
  public Boolean getDryRun() {
    return dryRun;
  }

  /**
   * [Optional] If set, don't actually run the query. A valid query will return an empty response,
   * while an invalid query will return the same error it would if it wasn't a dry run.
   * The value set may be {@code null}.
   */
  public QueryRequest setDryRun(Boolean dryRun) {
    this.dryRun = dryRun;
    return this;
  }

  /**
   * The resource type of the request.
   * The value returned may be {@code null}.
   */
  public String getKind() {
    return kind;
  }

  /**
   * The resource type of the request.
   * The value set may be {@code null}.
   */
  public QueryRequest setKind(String kind) {
    this.kind = kind;
    return this;
  }

  /**
   * [Optional] The maximum number of results to return per page of results. If the response list
   * exceeds the maximum response size for a single response, you will have to page through the
   * results. Default is to return the maximum response size.
   * The value returned may be {@code null}.
   */
  public Long getMaxResults() {
    return maxResults;
  }

  /**
   * [Optional] The maximum number of results to return per page of results. If the response list
   * exceeds the maximum response size for a single response, you will have to page through the
   * results. Default is to return the maximum response size.
   * The value set may be {@code null}.
   */
  public QueryRequest setMaxResults(Long maxResults) {
    this.maxResults = maxResults;
    return this;
  }

  /**
   * [Experimental] If set, preserve null values in table data, rather than mapping null values to
   * the column's default value. This flag currently defaults to false, but the default will soon be
   * changed to true. Shortly afterward, this flag will be removed completely. Please specify true
   * if possible, and false only if you need to force the old behavior while updating client code.
   * The value returned may be {@code null}.
   */
  public Boolean getPreserveNulls() {
    return preserveNulls;
  }

  /**
   * [Experimental] If set, preserve null values in table data, rather than mapping null values to
   * the column's default value. This flag currently defaults to false, but the default will soon be
   * changed to true. Shortly afterward, this flag will be removed completely. Please specify true
   * if possible, and false only if you need to force the old behavior while updating client code.
   * The value set may be {@code null}.
   */
  public QueryRequest setPreserveNulls(Boolean preserveNulls) {
    this.preserveNulls = preserveNulls;
    return this;
  }

  /**
   * [Required] A query string, following the BigQuery query syntax of the query to execute. Table
   * names should be qualified by dataset name in the format projectId:datasetId.tableId unless you
   * specify the defaultDataset value. If the table is in the same project as the job, you can omit
   * the project ID. Example: SELECT f1 FROM myProjectId:myDatasetId.myTableId.
   * The value returned may be {@code null}.
   */
  public String getQuery() {
    return query;
  }

  /**
   * [Required] A query string, following the BigQuery query syntax of the query to execute. Table
   * names should be qualified by dataset name in the format projectId:datasetId.tableId unless you
   * specify the defaultDataset value. If the table is in the same project as the job, you can omit
   * the project ID. Example: SELECT f1 FROM myProjectId:myDatasetId.myTableId.
   * The value set may be {@code null}.
   */
  public QueryRequest setQuery(String query) {
    this.query = query;
    return this;
  }

  /**
   * [Optional] How long to wait for the query to complete, in milliseconds, before returning.
   * Default is to return immediately. If the timeout passes before the job completes, the request
   * will fail with a TIMEOUT error.
   * The value returned may be {@code null}.
   */
  public Long getTimeoutMs() {
    return timeoutMs;
  }

  /**
   * [Optional] How long to wait for the query to complete, in milliseconds, before returning.
   * Default is to return immediately. If the timeout passes before the job completes, the request
   * will fail with a TIMEOUT error.
   * The value set may be {@code null}.
   */
  public QueryRequest setTimeoutMs(Long timeoutMs) {
    this.timeoutMs = timeoutMs;
    return this;
  }

  /**
   * [Optional] Whether to look for the result in the query cache. The query cache is a best-effort
   * cache that will be flushed whenever tables in the query are modified.
   * The value returned may be {@code null}.
   */
  public Boolean getUseQueryCache() {
    return useQueryCache;
  }

  /**
   * [Optional] Whether to look for the result in the query cache. The query cache is a best-effort
   * cache that will be flushed whenever tables in the query are modified.
   * The value set may be {@code null}.
   */
  public QueryRequest setUseQueryCache(Boolean useQueryCache) {
    this.useQueryCache = useQueryCache;
    return this;
  }

}
