/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.bigquery.model;

import com.google.api.client.json.GenericJson;
import com.google.api.client.json.JsonString;
import com.google.common.primitives.UnsignedLong;

/**
 * Model definition for QueryResponse.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the BigQuery API. For a detailed explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class QueryResponse extends GenericJson {

  /**
   * Whether the query result was fetched from the query cache.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Boolean cacheHit;

  /**
   * Whether the query has completed or not. If rows or totalRows are present, this will always be
   * true. If this is false, totalRows will not be available.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Boolean jobComplete;

  /**
   * Reference to the Job that was created to run the query. This field will be present even if the
   * original request timed out, in which case GetQueryResults can be used to read the results once
   * the query has completed. Since this API only returns the first page of results, subsequent
   * pages can be fetched via the same mechanism (GetQueryResults).
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private JobReference jobReference;

  /**
   * The resource type.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String kind;

  /**
   * A token used for paging results.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String pageToken;

  /**
   * An object with as many results as can be contained within the maximum permitted reply size. To
   * get any additional rows, you can call GetQueryResults and specify the jobReference returned
   * above.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<TableRow> rows;

  static {
    // hack to force ProGuard to consider TableRow used, since otherwise it would be stripped out
    // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
    com.google.api.client.util.Data.nullOf(TableRow.class);
  }

  /**
   * The schema of the results. Present only when the query completes successfully.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private TableSchema schema;

  /**
   * The total number of bytes processed for this query. If this query was a dry run, this is the
   * number of bytes that would be processed if the query were run.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key @JsonString
  private Long totalBytesProcessed;

  /**
   * The total number of rows in the complete query result set, which can be more than the number of
   * rows in this single page of results.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key @JsonString
  private UnsignedLong totalRows;

  /**
   * Whether the query result was fetched from the query cache.
   * The value returned may be {@code null}.
   */
  public Boolean getCacheHit() {
    return cacheHit;
  }

  /**
   * Whether the query result was fetched from the query cache.
   * The value set may be {@code null}.
   */
  public QueryResponse setCacheHit(Boolean cacheHit) {
    this.cacheHit = cacheHit;
    return this;
  }

  /**
   * Whether the query has completed or not. If rows or totalRows are present, this will always be
   * true. If this is false, totalRows will not be available.
   * The value returned may be {@code null}.
   */
  public Boolean getJobComplete() {
    return jobComplete;
  }

  /**
   * Whether the query has completed or not. If rows or totalRows are present, this will always be
   * true. If this is false, totalRows will not be available.
   * The value set may be {@code null}.
   */
  public QueryResponse setJobComplete(Boolean jobComplete) {
    this.jobComplete = jobComplete;
    return this;
  }

  /**
   * Reference to the Job that was created to run the query. This field will be present even if the
   * original request timed out, in which case GetQueryResults can be used to read the results once
   * the query has completed. Since this API only returns the first page of results, subsequent
   * pages can be fetched via the same mechanism (GetQueryResults).
   * The value returned may be {@code null}.
   */
  public JobReference getJobReference() {
    return jobReference;
  }

  /**
   * Reference to the Job that was created to run the query. This field will be present even if the
   * original request timed out, in which case GetQueryResults can be used to read the results once
   * the query has completed. Since this API only returns the first page of results, subsequent
   * pages can be fetched via the same mechanism (GetQueryResults).
   * The value set may be {@code null}.
   */
  public QueryResponse setJobReference(JobReference jobReference) {
    this.jobReference = jobReference;
    return this;
  }

  /**
   * The resource type.
   * The value returned may be {@code null}.
   */
  public String getKind() {
    return kind;
  }

  /**
   * The resource type.
   * The value set may be {@code null}.
   */
  public QueryResponse setKind(String kind) {
    this.kind = kind;
    return this;
  }

  /**
   * A token used for paging results.
   * The value returned may be {@code null}.
   */
  public String getPageToken() {
    return pageToken;
  }

  /**
   * A token used for paging results.
   * The value set may be {@code null}.
   */
  public QueryResponse setPageToken(String pageToken) {
    this.pageToken = pageToken;
    return this;
  }

  /**
   * An object with as many results as can be contained within the maximum permitted reply size. To
   * get any additional rows, you can call GetQueryResults and specify the jobReference returned
   * above.
   * The value returned may be {@code null}.
   */
  public java.util.List<TableRow> getRows() {
    return rows;
  }

  /**
   * An object with as many results as can be contained within the maximum permitted reply size. To
   * get any additional rows, you can call GetQueryResults and specify the jobReference returned
   * above.
   * The value set may be {@code null}.
   */
  public QueryResponse setRows(java.util.List<TableRow> rows) {
    this.rows = rows;
    return this;
  }

  /**
   * The schema of the results. Present only when the query completes successfully.
   * The value returned may be {@code null}.
   */
  public TableSchema getSchema() {
    return schema;
  }

  /**
   * The schema of the results. Present only when the query completes successfully.
   * The value set may be {@code null}.
   */
  public QueryResponse setSchema(TableSchema schema) {
    this.schema = schema;
    return this;
  }

  /**
   * The total number of bytes processed for this query. If this query was a dry run, this is the
   * number of bytes that would be processed if the query were run.
   * The value returned may be {@code null}.
   */
  public Long getTotalBytesProcessed() {
    return totalBytesProcessed;
  }

  /**
   * The total number of bytes processed for this query. If this query was a dry run, this is the
   * number of bytes that would be processed if the query were run.
   * The value set may be {@code null}.
   */
  public QueryResponse setTotalBytesProcessed(Long totalBytesProcessed) {
    this.totalBytesProcessed = totalBytesProcessed;
    return this;
  }

  /**
   * The total number of rows in the complete query result set, which can be more than the number of
   * rows in this single page of results.
   * The value returned may be {@code null}.
   */
  public UnsignedLong getTotalRows() {
    return totalRows;
  }

  /**
   * The total number of rows in the complete query result set, which can be more than the number of
   * rows in this single page of results.
   * The value set may be {@code null}.
   */
  public QueryResponse setTotalRows(UnsignedLong totalRows) {
    this.totalRows = totalRows;
    return this;
  }

}
