/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.bigquery.model;

import com.google.api.client.json.GenericJson;
import com.google.api.client.json.JsonString;
import com.google.common.primitives.UnsignedLong;

/**
 * Model definition for Table.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the BigQuery API. For a detailed explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class Table extends GenericJson {

  /**
   * [Output-only] The time when this table was created, in milliseconds since the epoch.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key @JsonString
  private Long creationTime;

  /**
   * [Optional] A user-friendly description of this table.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String description;

  /**
   * [Output-only] A hash of this resource.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String etag;

  /**
   * [Optional] The time when this table expires, in milliseconds since the epoch. If not present,
   * the table will persist indefinitely. Expired tables will be deleted and their storage
   * reclaimed.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key @JsonString
  private Long expirationTime;

  /**
   * [Optional] A descriptive name for this table.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String friendlyName;

  /**
   * [Output-only] An opaque ID uniquely identifying the table.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String id;

  /**
   * [Output-only] The type of the resource.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String kind;

  /**
   * [Output-only] The time when this table was last modified, in milliseconds since the epoch.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key @JsonString
  private Long lastModifiedTime;

  /**
   * [Output-only] The size of the table in bytes.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key @JsonString
  private Long numBytes;

  /**
   * [Output-only] The number of rows of data in this table.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key @JsonString
  private UnsignedLong numRows;

  /**
   * [Optional] Describes the schema of this table.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private TableSchema schema;

  /**
   * [Output-only] A URL that can be used to access this resource again.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String selfLink;

  /**
   * [Required] Reference describing the ID of this table.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private TableReference tableReference;

  /**
   * [Output-only] The time when this table was created, in milliseconds since the epoch.
   * The value returned may be {@code null}.
   */
  public Long getCreationTime() {
    return creationTime;
  }

  /**
   * [Output-only] The time when this table was created, in milliseconds since the epoch.
   * The value set may be {@code null}.
   */
  public Table setCreationTime(Long creationTime) {
    this.creationTime = creationTime;
    return this;
  }

  /**
   * [Optional] A user-friendly description of this table.
   * The value returned may be {@code null}.
   */
  public String getDescription() {
    return description;
  }

  /**
   * [Optional] A user-friendly description of this table.
   * The value set may be {@code null}.
   */
  public Table setDescription(String description) {
    this.description = description;
    return this;
  }

  /**
   * [Output-only] A hash of this resource.
   * The value returned may be {@code null}.
   */
  public String getEtag() {
    return etag;
  }

  /**
   * [Output-only] A hash of this resource.
   * The value set may be {@code null}.
   */
  public Table setEtag(String etag) {
    this.etag = etag;
    return this;
  }

  /**
   * [Optional] The time when this table expires, in milliseconds since the epoch. If not present,
   * the table will persist indefinitely. Expired tables will be deleted and their storage
   * reclaimed.
   * The value returned may be {@code null}.
   */
  public Long getExpirationTime() {
    return expirationTime;
  }

  /**
   * [Optional] The time when this table expires, in milliseconds since the epoch. If not present,
   * the table will persist indefinitely. Expired tables will be deleted and their storage
   * reclaimed.
   * The value set may be {@code null}.
   */
  public Table setExpirationTime(Long expirationTime) {
    this.expirationTime = expirationTime;
    return this;
  }

  /**
   * [Optional] A descriptive name for this table.
   * The value returned may be {@code null}.
   */
  public String getFriendlyName() {
    return friendlyName;
  }

  /**
   * [Optional] A descriptive name for this table.
   * The value set may be {@code null}.
   */
  public Table setFriendlyName(String friendlyName) {
    this.friendlyName = friendlyName;
    return this;
  }

  /**
   * [Output-only] An opaque ID uniquely identifying the table.
   * The value returned may be {@code null}.
   */
  public String getId() {
    return id;
  }

  /**
   * [Output-only] An opaque ID uniquely identifying the table.
   * The value set may be {@code null}.
   */
  public Table setId(String id) {
    this.id = id;
    return this;
  }

  /**
   * [Output-only] The type of the resource.
   * The value returned may be {@code null}.
   */
  public String getKind() {
    return kind;
  }

  /**
   * [Output-only] The type of the resource.
   * The value set may be {@code null}.
   */
  public Table setKind(String kind) {
    this.kind = kind;
    return this;
  }

  /**
   * [Output-only] The time when this table was last modified, in milliseconds since the epoch.
   * The value returned may be {@code null}.
   */
  public Long getLastModifiedTime() {
    return lastModifiedTime;
  }

  /**
   * [Output-only] The time when this table was last modified, in milliseconds since the epoch.
   * The value set may be {@code null}.
   */
  public Table setLastModifiedTime(Long lastModifiedTime) {
    this.lastModifiedTime = lastModifiedTime;
    return this;
  }

  /**
   * [Output-only] The size of the table in bytes.
   * The value returned may be {@code null}.
   */
  public Long getNumBytes() {
    return numBytes;
  }

  /**
   * [Output-only] The size of the table in bytes.
   * The value set may be {@code null}.
   */
  public Table setNumBytes(Long numBytes) {
    this.numBytes = numBytes;
    return this;
  }

  /**
   * [Output-only] The number of rows of data in this table.
   * The value returned may be {@code null}.
   */
  public UnsignedLong getNumRows() {
    return numRows;
  }

  /**
   * [Output-only] The number of rows of data in this table.
   * The value set may be {@code null}.
   */
  public Table setNumRows(UnsignedLong numRows) {
    this.numRows = numRows;
    return this;
  }

  /**
   * [Optional] Describes the schema of this table.
   * The value returned may be {@code null}.
   */
  public TableSchema getSchema() {
    return schema;
  }

  /**
   * [Optional] Describes the schema of this table.
   * The value set may be {@code null}.
   */
  public Table setSchema(TableSchema schema) {
    this.schema = schema;
    return this;
  }

  /**
   * [Output-only] A URL that can be used to access this resource again.
   * The value returned may be {@code null}.
   */
  public String getSelfLink() {
    return selfLink;
  }

  /**
   * [Output-only] A URL that can be used to access this resource again.
   * The value set may be {@code null}.
   */
  public Table setSelfLink(String selfLink) {
    this.selfLink = selfLink;
    return this;
  }

  /**
   * [Required] Reference describing the ID of this table.
   * The value returned may be {@code null}.
   */
  public TableReference getTableReference() {
    return tableReference;
  }

  /**
   * [Required] Reference describing the ID of this table.
   * The value set may be {@code null}.
   */
  public Table setTableReference(TableReference tableReference) {
    this.tableReference = tableReference;
    return this;
  }

}
